package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbJxcspmxStoreinventorychangesService;

import java.util.List;

/**
*
* 进销存商品明细报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbjxcspmxstoreinventorychanges")
public class SKcBbJxcspmxStoreinventorychangesController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbJxcspmxStoreinventorychangesService sKcBbJxcspmxStoreinventorychangesService;

    /**
    * 进销存商品明细报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbJxcspmxStoreinventorychangesAdd")
    public String add() {
        return prefix + "/SKcBbJxcspmxStoreinventorychangesAdd";
    }

    /**
    * 进销存商品明细报表 新增
    *
    * @return
    */
    @Log(title = "进销存商品明细报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbJxcspmxStoreinventorychangesAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbJxcspmxStoreinventorychangesService.addSKcBbJxcspmxStoreinventorychanges(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 进销存商品明细报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbJxcspmxStoreinventorychangesView")
    public String skcbbjxcspmxstoreinventorychangesListView() {
        return prefix + "/SKcBbJxcspmxStoreinventorychangesList";
    }

    /**
    * 进销存商品明细报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbJxcspmxStoreinventorychangesList")
    @PostMapping("/sKcBbJxcspmxStoreinventorychangesList")
    @ResponseBody
    public TableDataInfo skcbbjxcspmxstoreinventorychangesList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbJxcspmxStoreinventorychangesService.findSKcBbJxcspmxStoreinventorychangesList(pd);
        return getDataTable(pageData);
    }

    /**
    * 进销存商品明细报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "进销存商品明细报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbJxcspmxStoreinventorychangesRemove")
    @ResponseBody
    public AjaxResult skcbbjxcspmxstoreinventorychangesRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbJxcspmxStoreinventorychangesService.SKcBbJxcspmxStoreinventorychangesRemove(pd);
        return toAjax(integer);
    }

    /**
    * 进销存商品明细报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbJxcspmxStoreinventorychangesEdit/{id}")
    public String skcbbjxcspmxstoreinventorychangesView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbJxcspmxStoreinventorychangesService.findSKcBbJxcspmxStoreinventorychangesList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbjxcspmxstoreinventorychangesPageEdit";
        }
        return prefix+ "/skcbbjxcspmxstoreinventorychangesEdit";
    }

    /**
    * 进销存商品明细报表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "进销存商品明细报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbJxcspmxStoreinventorychangesEdit")
    @ResponseBody
    public AjaxResult skcbbjxcspmxstoreinventorychangesEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbJxcspmxStoreinventorychangesService.updateSKcBbJxcspmxStoreinventorychanges(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbjxcspmxstoreinventorychanges with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbjxcspmxstoreinventorychanges with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
