package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbReceiptorderitemsService;

import java.util.List;

/**
*
* 收货报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbreceiptorderitems")
public class SKcBbReceiptorderitemsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbReceiptorderitemsService sKcBbReceiptorderitemsService;

    /**
    * 收货报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbReceiptorderitemsAdd")
    public String add() {
        return prefix + "/SKcBbReceiptorderitemsAdd";
    }

    /**
    * 收货报表 新增
    *
    * @return
    */
    @Log(title = "收货报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbReceiptorderitemsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbReceiptorderitemsService.addSKcBbReceiptorderitems(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 收货报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbReceiptorderitemsView")
    public String skcbbreceiptorderitemsListView() {
        return prefix + "/SKcBbReceiptorderitemsList";
    }

    /**
    * 收货报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbReceiptorderitemsList")
    @PostMapping("/sKcBbReceiptorderitemsList")
    @ResponseBody
    public TableDataInfo skcbbreceiptorderitemsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbReceiptorderitemsService.findSKcBbReceiptorderitemsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 收货报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "收货报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbReceiptorderitemsRemove")
    @ResponseBody
    public AjaxResult skcbbreceiptorderitemsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbReceiptorderitemsService.SKcBbReceiptorderitemsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 收货报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbReceiptorderitemsEdit/{id}")
    public String skcbbreceiptorderitemsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbReceiptorderitemsService.findSKcBbReceiptorderitemsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbreceiptorderitemsPageEdit";
        }
        return prefix+ "/skcbbreceiptorderitemsEdit";
    }

    /**
    * 收货报表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "收货报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbReceiptorderitemsEdit")
    @ResponseBody
    public AjaxResult skcbbreceiptorderitemsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbReceiptorderitemsService.updateSKcBbReceiptorderitems(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbreceiptorderitems with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbreceiptorderitems with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
