package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbRefillingitemsService;

import java.util.List;

/**
*
* 装斗报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbrefillingitems")
public class SKcBbRefillingitemsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbRefillingitemsService sKcBbRefillingitemsService;

    /**
    * 装斗报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbRefillingitemsAdd")
    public String add() {
        return prefix + "/SKcBbRefillingitemsAdd";
    }

    /**
    * 装斗报表 新增
    *
    * @return
    */
    @Log(title = "装斗报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbRefillingitemsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbRefillingitemsService.addSKcBbRefillingitems(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 装斗报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbRefillingitemsView")
    public String skcbbrefillingitemsListView() {
        return prefix + "/SKcBbRefillingitemsList";
    }

    /**
    * 装斗报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbRefillingitemsList")
    @PostMapping("/sKcBbRefillingitemsList")
    @ResponseBody
    public TableDataInfo skcbbrefillingitemsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbRefillingitemsService.findSKcBbRefillingitemsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 装斗报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "装斗报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbRefillingitemsRemove")
    @ResponseBody
    public AjaxResult skcbbrefillingitemsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbRefillingitemsService.SKcBbRefillingitemsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 装斗报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbRefillingitemsEdit/{id}")
    public String skcbbrefillingitemsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbRefillingitemsService.findSKcBbRefillingitemsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbrefillingitemsPageEdit";
        }
        return prefix+ "/skcbbrefillingitemsEdit";
    }

    /**
    * 装斗报表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "装斗报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbRefillingitemsEdit")
    @ResponseBody
    public AjaxResult skcbbrefillingitemsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbRefillingitemsService.updateSKcBbRefillingitems(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbrefillingitems with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbrefillingitems with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
