package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbRequisitionorderitemsService;

import java.util.List;

/**
*
* 请货报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbrequisitionorderitems")
public class SKcBbRequisitionorderitemsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbRequisitionorderitemsService sKcBbRequisitionorderitemsService;

    /**
    * 请货报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbRequisitionorderitemsAdd")
    public String add() {
        return prefix + "/SKcBbRequisitionorderitemsAdd";
    }

    /**
    * 请货报表 新增
    *
    * @return
    */
    @Log(title = "请货报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbRequisitionorderitemsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbRequisitionorderitemsService.addSKcBbRequisitionorderitems(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 请货报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbRequisitionorderitemsView")
    public String skcbbrequisitionorderitemsListView() {
        return prefix + "/SKcBbRequisitionorderitemsList";
    }

    /**
    * 请货报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbRequisitionorderitemsList")
    @PostMapping("/sKcBbRequisitionorderitemsList")
    @ResponseBody
    public TableDataInfo skcbbrequisitionorderitemsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbRequisitionorderitemsService.findSKcBbRequisitionorderitemsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 请货报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "请货报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbRequisitionorderitemsRemove")
    @ResponseBody
    public AjaxResult skcbbrequisitionorderitemsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbRequisitionorderitemsService.SKcBbRequisitionorderitemsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 请货报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbRequisitionorderitemsEdit/{id}")
    public String skcbbrequisitionorderitemsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbRequisitionorderitemsService.findSKcBbRequisitionorderitemsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbrequisitionorderitemsPageEdit";
        }
        return prefix+ "/skcbbrequisitionorderitemsEdit";
    }

    /**
    * 请货报表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "请货报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbRequisitionorderitemsEdit")
    @ResponseBody
    public AjaxResult skcbbrequisitionorderitemsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbRequisitionorderitemsService.updateSKcBbRequisitionorderitems(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbrequisitionorderitems with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbrequisitionorderitems with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
