package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbRetailsalesService;

import java.util.List;

/**
*
* 零售报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbretailsales")
public class SKcBbRetailsalesController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbRetailsalesService sKcBbRetailsalesService;

    /**
    * 零售报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbRetailsalesAdd")
    public String add() {
        return prefix + "/SKcBbRetailsalesAdd";
    }

    /**
    * 零售报表 新增
    *
    * @return
    */
    @Log(title = "零售报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbRetailsalesAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbRetailsalesService.addSKcBbRetailsales(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 零售报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbRetailsalesView")
    public String skcbbretailsalesListView() {
        return prefix + "/SKcBbRetailsalesList";
    }

    /**
    * 零售报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbRetailsalesList")
    @PostMapping("/sKcBbRetailsalesList")
    @ResponseBody
    public TableDataInfo skcbbretailsalesList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbRetailsalesService.findSKcBbRetailsalesList(pd);
        return getDataTable(pageData);
    }

    /**
    * 零售报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "零售报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbRetailsalesRemove")
    @ResponseBody
    public AjaxResult skcbbretailsalesRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbRetailsalesService.SKcBbRetailsalesRemove(pd);
        return toAjax(integer);
    }

    /**
    * 零售报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbRetailsalesEdit/{id}")
    public String skcbbretailsalesView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbRetailsalesService.findSKcBbRetailsalesList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbretailsalesPageEdit";
        }
        return prefix+ "/skcbbretailsalesEdit";
    }

    /**
    * 零售报表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "零售报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbRetailsalesEdit")
    @ResponseBody
    public AjaxResult skcbbretailsalesEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbRetailsalesService.updateSKcBbRetailsales(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbretailsales with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbretailsales with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
