package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbReturnorderitemsService;

import java.util.List;

/**
*
* 退货记录报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbreturnorderitems")
public class SKcBbReturnorderitemsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbReturnorderitemsService sKcBbReturnorderitemsService;

    /**
    * 退货记录报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbReturnorderitemsAdd")
    public String add() {
        return prefix + "/SKcBbReturnorderitemsAdd";
    }

    /**
    * 退货记录报表 新增
    *
    * @return
    */
    @Log(title = "退货记录报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbReturnorderitemsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbReturnorderitemsService.addSKcBbReturnorderitems(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 退货记录报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbReturnorderitemsView")
    public String skcbbreturnorderitemsListView() {
        return prefix + "/SKcBbReturnorderitemsList";
    }

    /**
    * 退货记录报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbReturnorderitemsList")
    @PostMapping("/sKcBbReturnorderitemsList")
    @ResponseBody
    public TableDataInfo skcbbreturnorderitemsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbReturnorderitemsService.findSKcBbReturnorderitemsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 退货记录报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "退货记录报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbReturnorderitemsRemove")
    @ResponseBody
    public AjaxResult skcbbreturnorderitemsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbReturnorderitemsService.SKcBbReturnorderitemsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 退货记录报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbReturnorderitemsEdit/{id}")
    public String skcbbreturnorderitemsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbReturnorderitemsService.findSKcBbReturnorderitemsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbreturnorderitemsPageEdit";
        }
        return prefix+ "/skcbbreturnorderitemsEdit";
    }

    /**
    * 退货记录报表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "退货记录报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbReturnorderitemsEdit")
    @ResponseBody
    public AjaxResult skcbbreturnorderitemsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbReturnorderitemsService.updateSKcBbReturnorderitems(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbreturnorderitems with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbreturnorderitems with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
