package com.bzd.web.controller.kc.bb;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.bb.SKcBbStoreinventorycostService;

import java.util.List;

/**
*
* 门店进销存月汇总表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcbbstoreinventorycost")
public class SKcBbStoreinventorycostController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/bb";

    @Autowired
    private SKcBbStoreinventorycostService sKcBbStoreinventorycostService;

    /**
    * 门店进销存月汇总表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbStoreinventorycostAdd")
    public String add() {
        return prefix + "/SKcBbStoreinventorycostAdd";
    }

    /**
    * 门店进销存月汇总表 新增
    *
    * @return
    */
    @Log(title = "门店进销存月汇总表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcBbStoreinventorycostAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcBbStoreinventorycostService.addSKcBbStoreinventorycost(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店进销存月汇总表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:bb::view")
    @GetMapping("/sKcBbStoreinventorycostView")
    public String skcbbstoreinventorycostListView() {
        return prefix + "/SKcBbStoreinventorycostList";
    }

    /**
    * 门店进销存月汇总表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:sKcBbStoreinventorycostList")
    @PostMapping("/sKcBbStoreinventorycostList")
    @ResponseBody
    public TableDataInfo skcbbstoreinventorycostList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcBbStoreinventorycostService.findSKcBbStoreinventorycostList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店进销存月汇总表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:remove")
    @Log(title = "门店进销存月汇总表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcBbStoreinventorycostRemove")
    @ResponseBody
    public AjaxResult skcbbstoreinventorycostRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcBbStoreinventorycostService.SKcBbStoreinventorycostRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店进销存月汇总表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:bb:edit")
    @GetMapping("/sKcBbStoreinventorycostEdit/{id}")
    public String skcbbstoreinventorycostView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcBbStoreinventorycostService.findSKcBbStoreinventorycostList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcbbstoreinventorycostPageEdit";
        }
        return prefix+ "/skcbbstoreinventorycostEdit";
    }

    /**
    * 门店进销存月汇总表保存修改的数据
    */
    @RequiresPermissions("kc:bb:edit")
    @Log(title = "门店进销存月汇总表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcBbStoreinventorycostEdit")
    @ResponseBody
    public AjaxResult skcbbstoreinventorycostEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcBbStoreinventorycostService.updateSKcBbStoreinventorycost(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcbbstoreinventorycost with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcbbstoreinventorycost with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
