package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkArrivalinfoService;

import java.util.List;

/**
*
* 收货差异 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkarrivalinfo")
public class SKcCrkArrivalinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkArrivalinfoService sKcCrkArrivalinfoService;

    /**
    * 收货差异 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkArrivalinfoAdd")
    public String add() {
        return prefix + "/SKcCrkArrivalinfoAdd";
    }

    /**
    * 收货差异 新增
    *
    * @return
    */
    @Log(title = "收货差异新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkArrivalinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkArrivalinfoService.addSKcCrkArrivalinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 收货差异 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkArrivalinfoView")
    public String skccrkarrivalinfoListView() {
        return prefix + "/SKcCrkArrivalinfoList";
    }

    /**
    * 收货差异 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkArrivalinfoList")
    @PostMapping("/sKcCrkArrivalinfoList")
    @ResponseBody
    public TableDataInfo skccrkarrivalinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkArrivalinfoService.findSKcCrkArrivalinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 收货差异 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "收货差异删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkArrivalinfoRemove")
    @ResponseBody
    public AjaxResult skccrkarrivalinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkArrivalinfoService.SKcCrkArrivalinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 收货差异 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkArrivalinfoEdit/{id}")
    public String skccrkarrivalinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkArrivalinfoService.findSKcCrkArrivalinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkarrivalinfoPageEdit";
        }
        return prefix+ "/skccrkarrivalinfoEdit";
    }

    /**
    * 收货差异保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "收货差异修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkArrivalinfoEdit")
    @ResponseBody
    public AjaxResult skccrkarrivalinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkArrivalinfoService.updateSKcCrkArrivalinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkarrivalinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkarrivalinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
