package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkCkReceiptinfoService;

import java.util.List;

/**
*
* 门店收货表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkckreceiptinfo")
public class SKcCrkCkReceiptinfoController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkCkReceiptinfoService sKcCrkCkReceiptinfoService;

    /**
    * 门店收货表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkCkReceiptinfoAdd")
    public String add() {
        return prefix + "/SKcCrkCkReceiptinfoAdd";
    }

    /**
    * 门店收货表 新增
    *
    * @return
    */
    @Log(title = "门店收货表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkCkReceiptinfoAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkCkReceiptinfoService.addSKcCrkCkReceiptinfo(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店收货表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkCkReceiptinfoView")
    public String skccrkckreceiptinfoListView() {
        return prefix + "/SKcCrkCkReceiptinfoList";
    }

    /**
    * 门店收货表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkCkReceiptinfoList")
    @PostMapping("/sKcCrkCkReceiptinfoList")
    @ResponseBody
    public TableDataInfo skccrkckreceiptinfoList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkCkReceiptinfoService.findSKcCrkCkReceiptinfoList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店收货表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "门店收货表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkCkReceiptinfoRemove")
    @ResponseBody
    public AjaxResult skccrkckreceiptinfoRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkCkReceiptinfoService.SKcCrkCkReceiptinfoRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店收货表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkCkReceiptinfoEdit/{id}")
    public String skccrkckreceiptinfoView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkCkReceiptinfoService.findSKcCrkCkReceiptinfoList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkckreceiptinfoPageEdit";
        }
        return prefix+ "/skccrkckreceiptinfoEdit";
    }

    /**
    * 门店收货表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "门店收货表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkCkReceiptinfoEdit")
    @ResponseBody
    public AjaxResult skccrkckreceiptinfoEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkCkReceiptinfoService.updateSKcCrkCkReceiptinfo(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
