package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkDcshStorepurchasereceiptService;

import java.util.List;

/**
*
* 门店采购收货单信息表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkdcshstorepurchasereceipt")
public class SKcCrkDcshStorepurchasereceiptController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkDcshStorepurchasereceiptService sKcCrkDcshStorepurchasereceiptService;

    /**
    * 门店采购收货单信息表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkDcshStorepurchasereceiptAdd")
    public String add() {
        return prefix + "/SKcCrkDcshStorepurchasereceiptAdd";
    }

    /**
    * 门店采购收货单信息表 新增
    *
    * @return
    */
    @Log(title = "门店采购收货单信息表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkDcshStorepurchasereceiptAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkDcshStorepurchasereceiptService.addSKcCrkDcshStorepurchasereceipt(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店采购收货单信息表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkDcshStorepurchasereceiptView")
    public String skccrkdcshstorepurchasereceiptListView() {
        return prefix + "/SKcCrkDcshStorepurchasereceiptList";
    }

    /**
    * 门店采购收货单信息表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkDcshStorepurchasereceiptList")
    @PostMapping("/sKcCrkDcshStorepurchasereceiptList")
    @ResponseBody
    public TableDataInfo skccrkdcshstorepurchasereceiptList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkDcshStorepurchasereceiptService.findSKcCrkDcshStorepurchasereceiptList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店采购收货单信息表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "门店采购收货单信息表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkDcshStorepurchasereceiptRemove")
    @ResponseBody
    public AjaxResult skccrkdcshstorepurchasereceiptRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkDcshStorepurchasereceiptService.SKcCrkDcshStorepurchasereceiptRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店采购收货单信息表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkDcshStorepurchasereceiptEdit/{id}")
    public String skccrkdcshstorepurchasereceiptView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkDcshStorepurchasereceiptService.findSKcCrkDcshStorepurchasereceiptList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkdcshstorepurchasereceiptPageEdit";
        }
        return prefix+ "/skccrkdcshstorepurchasereceiptEdit";
    }

    /**
    * 门店采购收货单信息表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "门店采购收货单信息表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkDcshStorepurchasereceiptEdit")
    @ResponseBody
    public AjaxResult skccrkdcshstorepurchasereceiptEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkDcshStorepurchasereceiptService.updateSKcCrkDcshStorepurchasereceipt(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkdcshstorepurchasereceipt with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkdcshstorepurchasereceipt with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
