package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkDcthStorereturnorderService;

import java.util.List;

/**
*
* 门店采购退货单信息表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkdcthstorereturnorder")
public class SKcCrkDcthStorereturnorderController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkDcthStorereturnorderService sKcCrkDcthStorereturnorderService;

    /**
    * 门店采购退货单信息表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkDcthStorereturnorderAdd")
    public String add() {
        return prefix + "/SKcCrkDcthStorereturnorderAdd";
    }

    /**
    * 门店采购退货单信息表 新增
    *
    * @return
    */
    @Log(title = "门店采购退货单信息表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkDcthStorereturnorderAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkDcthStorereturnorderService.addSKcCrkDcthStorereturnorder(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店采购退货单信息表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkDcthStorereturnorderView")
    public String skccrkdcthstorereturnorderListView() {
        return prefix + "/SKcCrkDcthStorereturnorderList";
    }

    /**
    * 门店采购退货单信息表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkDcthStorereturnorderList")
    @PostMapping("/sKcCrkDcthStorereturnorderList")
    @ResponseBody
    public TableDataInfo skccrkdcthstorereturnorderList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkDcthStorereturnorderService.findSKcCrkDcthStorereturnorderList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店采购退货单信息表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "门店采购退货单信息表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkDcthStorereturnorderRemove")
    @ResponseBody
    public AjaxResult skccrkdcthstorereturnorderRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkDcthStorereturnorderService.SKcCrkDcthStorereturnorderRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店采购退货单信息表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkDcthStorereturnorderEdit/{id}")
    public String skccrkdcthstorereturnorderView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkDcthStorereturnorderService.findSKcCrkDcthStorereturnorderList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkdcthstorereturnorderPageEdit";
        }
        return prefix+ "/skccrkdcthstorereturnorderEdit";
    }

    /**
    * 门店采购退货单信息表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "门店采购退货单信息表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkDcthStorereturnorderEdit")
    @ResponseBody
    public AjaxResult skccrkdcthstorereturnorderEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkDcthStorereturnorderService.updateSKcCrkDcthStorereturnorder(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkdcthstorereturnorder with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkdcthstorereturnorder with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
