package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkDzysDeliveryorderService;

import java.util.List;

/**
*
* 电子验收单据 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkdzysdeliveryorder")
public class SKcCrkDzysDeliveryorderController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkDzysDeliveryorderService sKcCrkDzysDeliveryorderService;

    /**
    * 电子验收单据 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkDzysDeliveryorderAdd")
    public String add() {
        return prefix + "/SKcCrkDzysDeliveryorderAdd";
    }

    /**
    * 电子验收单据 新增
    *
    * @return
    */
    @Log(title = "电子验收单据新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkDzysDeliveryorderAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkDzysDeliveryorderService.addSKcCrkDzysDeliveryorder(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 电子验收单据 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkDzysDeliveryorderView")
    public String skccrkdzysdeliveryorderListView() {
        return prefix + "/SKcCrkDzysDeliveryorderList";
    }

    /**
    * 电子验收单据 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkDzysDeliveryorderList")
    @PostMapping("/sKcCrkDzysDeliveryorderList")
    @ResponseBody
    public TableDataInfo skccrkdzysdeliveryorderList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkDzysDeliveryorderService.findSKcCrkDzysDeliveryorderList(pd);
        return getDataTable(pageData);
    }

    /**
    * 电子验收单据 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "电子验收单据删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkDzysDeliveryorderRemove")
    @ResponseBody
    public AjaxResult skccrkdzysdeliveryorderRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkDzysDeliveryorderService.SKcCrkDzysDeliveryorderRemove(pd);
        return toAjax(integer);
    }

    /**
    * 电子验收单据 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkDzysDeliveryorderEdit/{id}")
    public String skccrkdzysdeliveryorderView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkDzysDeliveryorderService.findSKcCrkDzysDeliveryorderList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkdzysdeliveryorderPageEdit";
        }
        return prefix+ "/skccrkdzysdeliveryorderEdit";
    }

    /**
    * 电子验收单据保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "电子验收单据修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkDzysDeliveryorderEdit")
    @ResponseBody
    public AjaxResult skccrkdzysdeliveryorderEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkDzysDeliveryorderService.updateSKcCrkDzysDeliveryorder(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkdzysdeliveryorder with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkdzysdeliveryorder with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
