package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkMdqhdRequisitionorderService;

import java.util.List;

/**
*
* 门店请货单信息表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkmdqhdrequisitionorder")
public class SKcCrkMdqhdRequisitionorderController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkMdqhdRequisitionorderService sKcCrkMdqhdRequisitionorderService;

    /**
    * 门店请货单信息表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkMdqhdRequisitionorderAdd")
    public String add() {
        return prefix + "/SKcCrkMdqhdRequisitionorderAdd";
    }

    /**
    * 门店请货单信息表 新增
    *
    * @return
    */
    @Log(title = "门店请货单信息表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkMdqhdRequisitionorderAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkMdqhdRequisitionorderService.addSKcCrkMdqhdRequisitionorder(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店请货单信息表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkMdqhdRequisitionorderView")
    public String skccrkmdqhdrequisitionorderListView() {
        return prefix + "/SKcCrkMdqhdRequisitionorderList";
    }

    /**
    * 门店请货单信息表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkMdqhdRequisitionorderList")
    @PostMapping("/sKcCrkMdqhdRequisitionorderList")
    @ResponseBody
    public TableDataInfo skccrkmdqhdrequisitionorderList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkMdqhdRequisitionorderService.findSKcCrkMdqhdRequisitionorderList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店请货单信息表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "门店请货单信息表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkMdqhdRequisitionorderRemove")
    @ResponseBody
    public AjaxResult skccrkmdqhdrequisitionorderRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkMdqhdRequisitionorderService.SKcCrkMdqhdRequisitionorderRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店请货单信息表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkMdqhdRequisitionorderEdit/{id}")
    public String skccrkmdqhdrequisitionorderView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkMdqhdRequisitionorderService.findSKcCrkMdqhdRequisitionorderList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkmdqhdrequisitionorderPageEdit";
        }
        return prefix+ "/skccrkmdqhdrequisitionorderEdit";
    }

    /**
    * 门店请货单信息表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "门店请货单信息表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkMdqhdRequisitionorderEdit")
    @ResponseBody
    public AjaxResult skccrkmdqhdrequisitionorderEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkMdqhdRequisitionorderService.updateSKcCrkMdqhdRequisitionorder(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkmdqhdrequisitionorder with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkmdqhdrequisitionorder with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
