package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkThReturnService;

import java.util.List;

/**
*
* 退货表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkthreturn")
public class SKcCrkThReturnController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkThReturnService sKcCrkThReturnService;

    /**
    * 退货表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkThReturnAdd")
    public String add() {
        return prefix + "/SKcCrkThReturnAdd";
    }

    /**
    * 退货表 新增
    *
    * @return
    */
    @Log(title = "退货表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkThReturnAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkThReturnService.addSKcCrkThReturn(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 退货表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkThReturnView")
    public String skccrkthreturnListView() {
        return prefix + "/SKcCrkThReturnList";
    }

    /**
    * 退货表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkThReturnList")
    @PostMapping("/sKcCrkThReturnList")
    @ResponseBody
    public TableDataInfo skccrkthreturnList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkThReturnService.findSKcCrkThReturnList(pd);
        return getDataTable(pageData);
    }

    /**
    * 退货表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "退货表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkThReturnRemove")
    @ResponseBody
    public AjaxResult skccrkthreturnRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkThReturnService.SKcCrkThReturnRemove(pd);
        return toAjax(integer);
    }

    /**
    * 退货表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkThReturnEdit/{id}")
    public String skccrkthreturnView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkThReturnService.findSKcCrkThReturnList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkthreturnPageEdit";
        }
        return prefix+ "/skccrkthreturnEdit";
    }

    /**
    * 退货表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "退货表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkThReturnEdit")
    @ResponseBody
    public AjaxResult skccrkthreturnEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkThReturnService.updateSKcCrkThReturn(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkthreturn with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkthreturn with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
