package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkThshReturndocumentService;

import java.util.List;

/**
*
* 退货申请表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkthshreturndocument")
public class SKcCrkThshReturndocumentController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkThshReturndocumentService sKcCrkThshReturndocumentService;

    /**
    * 退货申请表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkThshReturndocumentAdd")
    public String add() {
        return prefix + "/SKcCrkThshReturndocumentAdd";
    }

    /**
    * 退货申请表 新增
    *
    * @return
    */
    @Log(title = "退货申请表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkThshReturndocumentAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkThshReturndocumentService.addSKcCrkThshReturndocument(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 退货申请表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkThshReturndocumentView")
    public String skccrkthshreturndocumentListView() {
        return prefix + "/SKcCrkThshReturndocumentList";
    }

    /**
    * 退货申请表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkThshReturndocumentList")
    @PostMapping("/sKcCrkThshReturndocumentList")
    @ResponseBody
    public TableDataInfo skccrkthshreturndocumentList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkThshReturndocumentService.findSKcCrkThshReturndocumentList(pd);
        return getDataTable(pageData);
    }

    /**
    * 退货申请表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "退货申请表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkThshReturndocumentRemove")
    @ResponseBody
    public AjaxResult skccrkthshreturndocumentRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkThshReturndocumentService.SKcCrkThshReturndocumentRemove(pd);
        return toAjax(integer);
    }

    /**
    * 退货申请表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkThshReturndocumentEdit/{id}")
    public String skccrkthshreturndocumentView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkThshReturndocumentService.findSKcCrkThshReturndocumentList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkthshreturndocumentPageEdit";
        }
        return prefix+ "/skccrkthshreturndocumentEdit";
    }

    /**
    * 退货申请表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "退货申请表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkThshReturndocumentEdit")
    @ResponseBody
    public AjaxResult skccrkthshreturndocumentEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkThshReturndocumentService.updateSKcCrkThshReturndocument(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkthshreturndocument with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkthshreturndocument with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
