package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkWeeklyrequisitionstatsService;

import java.util.List;

/**
*
* 门店请货满足率 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkweeklyrequisitionstats")
public class SKcCrkWeeklyrequisitionstatsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkWeeklyrequisitionstatsService sKcCrkWeeklyrequisitionstatsService;

    /**
    * 门店请货满足率 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkWeeklyrequisitionstatsAdd")
    public String add() {
        return prefix + "/SKcCrkWeeklyrequisitionstatsAdd";
    }

    /**
    * 门店请货满足率 新增
    *
    * @return
    */
    @Log(title = "门店请货满足率新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkWeeklyrequisitionstatsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkWeeklyrequisitionstatsService.addSKcCrkWeeklyrequisitionstats(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 门店请货满足率 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkWeeklyrequisitionstatsView")
    public String skccrkweeklyrequisitionstatsListView() {
        return prefix + "/SKcCrkWeeklyrequisitionstatsList";
    }

    /**
    * 门店请货满足率 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkWeeklyrequisitionstatsList")
    @PostMapping("/sKcCrkWeeklyrequisitionstatsList")
    @ResponseBody
    public TableDataInfo skccrkweeklyrequisitionstatsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkWeeklyrequisitionstatsService.findSKcCrkWeeklyrequisitionstatsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 门店请货满足率 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "门店请货满足率删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkWeeklyrequisitionstatsRemove")
    @ResponseBody
    public AjaxResult skccrkweeklyrequisitionstatsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkWeeklyrequisitionstatsService.SKcCrkWeeklyrequisitionstatsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 门店请货满足率 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkWeeklyrequisitionstatsEdit/{id}")
    public String skccrkweeklyrequisitionstatsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkWeeklyrequisitionstatsService.findSKcCrkWeeklyrequisitionstatsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkweeklyrequisitionstatsPageEdit";
        }
        return prefix+ "/skccrkweeklyrequisitionstatsEdit";
    }

    /**
    * 门店请货满足率保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "门店请货满足率修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkWeeklyrequisitionstatsEdit")
    @ResponseBody
    public AjaxResult skccrkweeklyrequisitionstatsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkWeeklyrequisitionstatsService.updateSKcCrkWeeklyrequisitionstats(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkweeklyrequisitionstats with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkweeklyrequisitionstats with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
