package com.bzd.web.controller.kc.crk;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.crk.SKcCrkYsrkCheckinService;

import java.util.List;

/**
*
* 验收入库表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skccrkysrkcheckin")
public class SKcCrkYsrkCheckinController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/crk";

    @Autowired
    private SKcCrkYsrkCheckinService sKcCrkYsrkCheckinService;

    /**
    * 验收入库表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkYsrkCheckinAdd")
    public String add() {
        return prefix + "/SKcCrkYsrkCheckinAdd";
    }

    /**
    * 验收入库表 新增
    *
    * @return
    */
    @Log(title = "验收入库表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcCrkYsrkCheckinAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcCrkYsrkCheckinService.addSKcCrkYsrkCheckin(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 验收入库表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:crk::view")
    @GetMapping("/sKcCrkYsrkCheckinView")
    public String skccrkysrkcheckinListView() {
        return prefix + "/SKcCrkYsrkCheckinList";
    }

    /**
    * 验收入库表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:sKcCrkYsrkCheckinList")
    @PostMapping("/sKcCrkYsrkCheckinList")
    @ResponseBody
    public TableDataInfo skccrkysrkcheckinList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcCrkYsrkCheckinService.findSKcCrkYsrkCheckinList(pd);
        return getDataTable(pageData);
    }

    /**
    * 验收入库表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:remove")
    @Log(title = "验收入库表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcCrkYsrkCheckinRemove")
    @ResponseBody
    public AjaxResult skccrkysrkcheckinRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcCrkYsrkCheckinService.SKcCrkYsrkCheckinRemove(pd);
        return toAjax(integer);
    }

    /**
    * 验收入库表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:crk:edit")
    @GetMapping("/sKcCrkYsrkCheckinEdit/{id}")
    public String skccrkysrkcheckinView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcCrkYsrkCheckinService.findSKcCrkYsrkCheckinList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skccrkysrkcheckinPageEdit";
        }
        return prefix+ "/skccrkysrkcheckinEdit";
    }

    /**
    * 验收入库表保存修改的数据
    */
    @RequiresPermissions("kc:crk:edit")
    @Log(title = "验收入库表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcCrkYsrkCheckinEdit")
    @ResponseBody
    public AjaxResult skccrkysrkcheckinEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcCrkYsrkCheckinService.updateSKcCrkYsrkCheckin(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skccrkysrkcheckin with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skccrkysrkcheckin with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
