package com.bzd.web.controller.kc.kn;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.kn.SKcKnAdjustmentdocumentService;

import java.util.List;

/**
*
* 报损报溢申请表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcknadjustmentdocument")
public class SKcKnAdjustmentdocumentController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/kn";

    @Autowired
    private SKcKnAdjustmentdocumentService sKcKnAdjustmentdocumentService;

    /**
    * 报损报溢申请表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnAdjustmentdocumentAdd")
    public String add() {
        return prefix + "/SKcKnAdjustmentdocumentAdd";
    }

    /**
    * 报损报溢申请表 新增
    *
    * @return
    */
    @Log(title = "报损报溢申请表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcKnAdjustmentdocumentAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcKnAdjustmentdocumentService.addSKcKnAdjustmentdocument(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 报损报溢申请表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnAdjustmentdocumentView")
    public String skcknadjustmentdocumentListView() {
        return prefix + "/SKcKnAdjustmentdocumentList";
    }

    /**
    * 报损报溢申请表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:sKcKnAdjustmentdocumentList")
    @PostMapping("/sKcKnAdjustmentdocumentList")
    @ResponseBody
    public TableDataInfo skcknadjustmentdocumentList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcKnAdjustmentdocumentService.findSKcKnAdjustmentdocumentList(pd);
        return getDataTable(pageData);
    }

    /**
    * 报损报溢申请表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:remove")
    @Log(title = "报损报溢申请表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcKnAdjustmentdocumentRemove")
    @ResponseBody
    public AjaxResult skcknadjustmentdocumentRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcKnAdjustmentdocumentService.SKcKnAdjustmentdocumentRemove(pd);
        return toAjax(integer);
    }

    /**
    * 报损报溢申请表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:edit")
    @GetMapping("/sKcKnAdjustmentdocumentEdit/{id}")
    public String skcknadjustmentdocumentView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcKnAdjustmentdocumentService.findSKcKnAdjustmentdocumentList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcknadjustmentdocumentPageEdit";
        }
        return prefix+ "/skcknadjustmentdocumentEdit";
    }

    /**
    * 报损报溢申请表保存修改的数据
    */
    @RequiresPermissions("kc:kn:edit")
    @Log(title = "报损报溢申请表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcKnAdjustmentdocumentEdit")
    @ResponseBody
    public AjaxResult skcknadjustmentdocumentEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcKnAdjustmentdocumentService.updateSKcKnAdjustmentdocument(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcknadjustmentdocument with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcknadjustmentdocument with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
