package com.bzd.web.controller.kc.kn;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.kn.SKcKnKyspStoredocumentService;

import java.util.List;

/**
*
* 可疑商品处理 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcknkyspstoredocument")
public class SKcKnKyspStoredocumentController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/kn";

    @Autowired
    private SKcKnKyspStoredocumentService sKcKnKyspStoredocumentService;

    /**
    * 可疑商品处理 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnKyspStoredocumentAdd")
    public String add() {
        return prefix + "/SKcKnKyspStoredocumentAdd";
    }

    /**
    * 可疑商品处理 新增
    *
    * @return
    */
    @Log(title = "可疑商品处理新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcKnKyspStoredocumentAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcKnKyspStoredocumentService.addSKcKnKyspStoredocument(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 可疑商品处理 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnKyspStoredocumentView")
    public String skcknkyspstoredocumentListView() {
        return prefix + "/SKcKnKyspStoredocumentList";
    }

    /**
    * 可疑商品处理 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:sKcKnKyspStoredocumentList")
    @PostMapping("/sKcKnKyspStoredocumentList")
    @ResponseBody
    public TableDataInfo skcknkyspstoredocumentList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcKnKyspStoredocumentService.findSKcKnKyspStoredocumentList(pd);
        return getDataTable(pageData);
    }

    /**
    * 可疑商品处理 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:remove")
    @Log(title = "可疑商品处理删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcKnKyspStoredocumentRemove")
    @ResponseBody
    public AjaxResult skcknkyspstoredocumentRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcKnKyspStoredocumentService.SKcKnKyspStoredocumentRemove(pd);
        return toAjax(integer);
    }

    /**
    * 可疑商品处理 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:edit")
    @GetMapping("/sKcKnKyspStoredocumentEdit/{id}")
    public String skcknkyspstoredocumentView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcKnKyspStoredocumentService.findSKcKnKyspStoredocumentList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcknkyspstoredocumentPageEdit";
        }
        return prefix+ "/skcknkyspstoredocumentEdit";
    }

    /**
    * 可疑商品处理保存修改的数据
    */
    @RequiresPermissions("kc:kn:edit")
    @Log(title = "可疑商品处理修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcKnKyspStoredocumentEdit")
    @ResponseBody
    public AjaxResult skcknkyspstoredocumentEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcKnKyspStoredocumentService.updateSKcKnKyspStoredocument(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcknkyspstoredocument with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcknkyspstoredocument with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
