package com.bzd.web.controller.kc.kn;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.kn.SKcKnQdjlCleaningitemsService;

import java.util.List;

/**
*
* 清斗报表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcknqdjlcleaningitems")
public class SKcKnQdjlCleaningitemsController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/kn";

    @Autowired
    private SKcKnQdjlCleaningitemsService sKcKnQdjlCleaningitemsService;

    /**
    * 清斗报表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnQdjlCleaningitemsAdd")
    public String add() {
        return prefix + "/SKcKnQdjlCleaningitemsAdd";
    }

    /**
    * 清斗报表 新增
    *
    * @return
    */
    @Log(title = "清斗报表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcKnQdjlCleaningitemsAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcKnQdjlCleaningitemsService.addSKcKnQdjlCleaningitems(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 清斗报表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnQdjlCleaningitemsView")
    public String skcknqdjlcleaningitemsListView() {
        return prefix + "/SKcKnQdjlCleaningitemsList";
    }

    /**
    * 清斗报表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:sKcKnQdjlCleaningitemsList")
    @PostMapping("/sKcKnQdjlCleaningitemsList")
    @ResponseBody
    public TableDataInfo skcknqdjlcleaningitemsList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcKnQdjlCleaningitemsService.findSKcKnQdjlCleaningitemsList(pd);
        return getDataTable(pageData);
    }

    /**
    * 清斗报表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:remove")
    @Log(title = "清斗报表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcKnQdjlCleaningitemsRemove")
    @ResponseBody
    public AjaxResult skcknqdjlcleaningitemsRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcKnQdjlCleaningitemsService.SKcKnQdjlCleaningitemsRemove(pd);
        return toAjax(integer);
    }

    /**
    * 清斗报表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:edit")
    @GetMapping("/sKcKnQdjlCleaningitemsEdit/{id}")
    public String skcknqdjlcleaningitemsView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcKnQdjlCleaningitemsService.findSKcKnQdjlCleaningitemsList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcknqdjlcleaningitemsPageEdit";
        }
        return prefix+ "/skcknqdjlcleaningitemsEdit";
    }

    /**
    * 清斗报表保存修改的数据
    */
    @RequiresPermissions("kc:kn:edit")
    @Log(title = "清斗报表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcKnQdjlCleaningitemsEdit")
    @ResponseBody
    public AjaxResult skcknqdjlcleaningitemsEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcKnQdjlCleaningitemsService.updateSKcKnQdjlCleaningitems(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcknqdjlcleaningitems with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcknqdjlcleaningitems with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
