package com.bzd.web.controller.kc.kn;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.kn.SKcKnStoragelocationService;

import java.util.List;

/**
*
* 货位管理信息表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skcknstoragelocation")
public class SKcKnStoragelocationController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/kn";

    @Autowired
    private SKcKnStoragelocationService sKcKnStoragelocationService;

    /**
    * 货位管理信息表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnStoragelocationAdd")
    public String add() {
        return prefix + "/SKcKnStoragelocationAdd";
    }

    /**
    * 货位管理信息表 新增
    *
    * @return
    */
    @Log(title = "货位管理信息表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcKnStoragelocationAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcKnStoragelocationService.addSKcKnStoragelocation(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 货位管理信息表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnStoragelocationView")
    public String skcknstoragelocationListView() {
        return prefix + "/SKcKnStoragelocationList";
    }

    /**
    * 货位管理信息表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:sKcKnStoragelocationList")
    @PostMapping("/sKcKnStoragelocationList")
    @ResponseBody
    public TableDataInfo skcknstoragelocationList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcKnStoragelocationService.findSKcKnStoragelocationList(pd);
        return getDataTable(pageData);
    }

    /**
    * 货位管理信息表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:remove")
    @Log(title = "货位管理信息表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcKnStoragelocationRemove")
    @ResponseBody
    public AjaxResult skcknstoragelocationRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcKnStoragelocationService.SKcKnStoragelocationRemove(pd);
        return toAjax(integer);
    }

    /**
    * 货位管理信息表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:edit")
    @GetMapping("/sKcKnStoragelocationEdit/{id}")
    public String skcknstoragelocationView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcKnStoragelocationService.findSKcKnStoragelocationList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skcknstoragelocationPageEdit";
        }
        return prefix+ "/skcknstoragelocationEdit";
    }

    /**
    * 货位管理信息表保存修改的数据
    */
    @RequiresPermissions("kc:kn:edit")
    @Log(title = "货位管理信息表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcKnStoragelocationEdit")
    @ResponseBody
    public AjaxResult skcknstoragelocationEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcKnStoragelocationService.updateSKcKnStoragelocation(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skcknstoragelocation with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skcknstoragelocation with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
