package com.bzd.web.controller.kc.kn;

import com.bzd.common.annotation.Log;
import com.bzd.common.config.dao.PageData;
import com.bzd.common.core.controller.BaseController;
import com.bzd.common.core.domain.AjaxResult;
import com.bzd.common.core.page.TableDataInfo;
import com.bzd.common.enums.BusinessType;
import com.bzd.system.service.PharmaceuticalService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.bzd.system.service.kc.kn.SKcKnTransferzonedocumentService;

import java.util.List;

/**
*
* 转库区管理表 前端控制器Controller
* @author LiXiangFei
* @since 2024-10-14
*/
@Controller
@RequestMapping(value = "kc/skckntransferzonedocument")
public class SKcKnTransferzonedocumentController extends BaseController {

    // 页面跳转前缀
    private String prefix = "kc/kn";

    @Autowired
    private SKcKnTransferzonedocumentService sKcKnTransferzonedocumentService;

    /**
    * 转库区管理表 新增页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnTransferzonedocumentAdd")
    public String add() {
        return prefix + "/SKcKnTransferzonedocumentAdd";
    }

    /**
    * 转库区管理表 新增
    *
    * @return
    */
    @Log(title = "转库区管理表新增", businessType = BusinessType.INSERT)
    @PostMapping("/sKcKnTransferzonedocumentAdd")
    @ResponseBody
    public AjaxResult addSave() throws Exception {
        PageData pd = this.getPageData();
        try {
            Integer result = sKcKnTransferzonedocumentService.addSKcKnTransferzonedocument(pd);
            if (result == 1) {
                return AjaxResult.success("新增成功");
            } else {
                logger.error("Failed to update 表skccrkckreceiptinfo with ID: {}", pd.get("id"));
                return AjaxResult.error("新增失败");
            }
        } catch (Exception e) {
            logger.error("Error occurred while updating 表skccrkckreceiptinfo with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }

    /**
    * 转库区管理表 查询页面跳转
    *
    * @return
    */
    @RequiresPermissions("kc:kn::view")
    @GetMapping("/sKcKnTransferzonedocumentView")
    public String skckntransferzonedocumentListView() {
        return prefix + "/SKcKnTransferzonedocumentList";
    }

    /**
    * 转库区管理表 数据查询
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:sKcKnTransferzonedocumentList")
    @PostMapping("/sKcKnTransferzonedocumentList")
    @ResponseBody
    public TableDataInfo skckntransferzonedocumentList() throws Exception {
    PageData pd = this.getPageData();
    startPage();
    List<PageData> pageData = sKcKnTransferzonedocumentService.findSKcKnTransferzonedocumentList(pd);
        return getDataTable(pageData);
    }

    /**
    * 转库区管理表 数据删除 根据id
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:remove")
    @Log(title = "转库区管理表删除", businessType = BusinessType.DELETE)
    @PostMapping("/sKcKnTransferzonedocumentRemove")
    @ResponseBody
    public AjaxResult skckntransferzonedocumentRemove() throws Exception {
        PageData pd = this.getPageData();
        Integer integer = sKcKnTransferzonedocumentService.SKcKnTransferzonedocumentRemove(pd);
        return toAjax(integer);
    }

    /**
    * 转库区管理表 数据修改
    *
    * @return
    * @throws Exception
    */
    @RequiresPermissions("kc:kn:edit")
    @GetMapping("/sKcKnTransferzonedocumentEdit/{id}")
    public String skckntransferzonedocumentView(@PathVariable("id") Long id, ModelMap mmap) throws Exception {
        PageData pd = this.getPageData();
        pd.put("id", id);
        PageData pageData = sKcKnTransferzonedocumentService.findSKcKnTransferzonedocumentList(pd).get(0);
        mmap.putAll(pageData);
        if(null!=pd.getString("status")){
            return prefix+ "/skckntransferzonedocumentPageEdit";
        }
        return prefix+ "/skckntransferzonedocumentEdit";
    }

    /**
    * 转库区管理表保存修改的数据
    */
    @RequiresPermissions("kc:kn:edit")
    @Log(title = "转库区管理表修改", businessType = BusinessType.UPDATE)
    @PostMapping("/sKcKnTransferzonedocumentEdit")
    @ResponseBody
    public AjaxResult skckntransferzonedocumentEditSave() throws Exception {
        PageData pd = this.getPageData();
        pd.put("up", "up");
        try {
            Integer updateResult = sKcKnTransferzonedocumentService.updateSKcKnTransferzonedocument(pd);
            if (updateResult == 1) {
                // 成功更新
                return AjaxResult.success("修改成功");
            } else {
                // 更新失败
                logger.error("Failed to update 表skckntransferzonedocument with ID: {}", pd.get("id"));
                return AjaxResult.error("修改失败");
            }
        } catch (Exception e) {
            // 异常处理
            logger.error("Error occurred while updating 表skckntransferzonedocument with ID: {}, Exception: {}", pd.get("id"), e.getMessage(), e);
            return AjaxResult.error("系统异常：" + e.getMessage());
        }
    }
}
